@@ -1,5 +1,5 @@
 /* idn2.c - command line interface to libidn2
-   Copyright (C) 2011-2016 Simon Josefsson
+   Copyright (C) 2011-2017 Simon Josefsson
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -42,12 +42,6 @@
 
 #include "blurbs.h"
 
-#define GREETING							\
-  "Copyright (C) 2011-2016  Simon Josefsson\n"				\
-  "This program comes with ABSOLUTELY NO WARRANTY; for details type `show w'.\n" \
-  "This is free software, and you are welcome to redistribute it\n" \
-  "under certain conditions; type `show c' for details.\n\n"
-
 const char version_etc_copyright[] =
   /* Do *not* mark this string for translation.  %s is a copyright
      symbol suitable for this locale, and %d is the copyright
@@ -114,7 +108,7 @@ hexdump (const char *prefix, const char *str)
 
   for (i = 0; i < strlen (str); i++)
     fprintf (stderr, "%s[%lu] = 0x%02x\n",
-	     prefix, (unsigned long) i, str[i] & 0xFF);
+	     prefix, (unsigned long) i, (unsigned) (str[i] & 0xFF));
 
   if (u8 && strcmp (str, (char *) u8) != 0)
     for (i = 0; i < strlen ((char *) u8); i++)
@@ -214,7 +208,7 @@ main (int argc, char *argv[])
     flags = IDN2_NONTRANSITIONAL;
 
   for (cmdn = 0; cmdn < args_info.inputs_num; cmdn++)
-    process_input (args_info.inputs[cmdn], flags);
+    process_input (args_info.inputs[cmdn], flags | IDN2_NFC_INPUT);
 
   if (!cmdn)
     {
